@@ -9,11 +9,11 @@ Sort::ByExample - sort lists to look like the example you provide
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =cut
 
-our $VERSION = '0.001';
+our $VERSION = '0.002';
 
 =head1 SYNOPSIS
 
@@ -39,7 +39,7 @@ provide a fallback sub for sorting unknown or equally-positioned data.
 
 =cut
 
-use Params::Util qw(_HASHLIKE _ARRAYLIKE);
+use Params::Util qw(_HASHLIKE _ARRAYLIKE _CODELIKE);
 use Sub::Exporter -setup => {
   exports => [ qw(sbe) ],
 };
@@ -49,6 +49,7 @@ use Sub::Exporter -setup => {
 =head2 sbe
 
   my $sorter = sbe($example, $fallback);
+  my $sorter = sbe($example, \%arg);
 
 This function returns a subroutine that will sort lists to look more like the
 example list.
@@ -62,22 +63,69 @@ Alternately, the example may be a reference to a hash.  Values are used to
 provide sort orders for input values.  Input values with the same sort value
 are sorted by the fallback sub, if given.
 
+If given named arguments as C<%arg>, valid arguments are:
+
+  fallback - a sub to sort data 
+  xform    - a sub to transform each item into the key to sort
+
+If no other named arguments are needed, the fallback sub may be given in place
+of the arg hashref.
+
 The fallback sub should accept two inputs and return either 1, 0, or -1, like a
 normal sorting routine.  The data to be sorted are passed as parameters.  For
 uninteresting reasons, C<$a> and C<$b> can't be used.
 
+The xform sub should accept one argument and return the data by which to sort
+that argument.  In other words, to sort a group of athletes by their medals:
+
+  my $sorter = sbe(
+    [ qw(Gold  Silver Bronze) ],
+    {
+      xform => sub { $_[0]->medal_metal },
+    },
+  );
+
+If both xform and fallback are given, then four arguments are passed to
+fallback:
+
+  a_xform, b_xform, a_original, b_original
+
 C<sbe> is only exported by request.
 
 =cut
 
 sub sbe {
-  my ($example, $fallback) = @_;
+  my ($example, $arg) = @_;
+
+  my $fallback;
+  if (_HASHLIKE($arg)) {
+    $fallback = $arg->{fallback};
+  } else {
+    $fallback = $arg;
+    $arg = {};
+  }
+
+  Carp::croak "invalid fallback routine"
+    if $fallback and not _CODELIKE($fallback);
 
   my $score = 0;
   my %score = _HASHLIKE($example)  ? %$example
             : _ARRAYLIKE($example) ? (map { $_ => $score++ } @$example)
             : Carp::confess "invalid data passed to sbe";
 
+  if (my $xf = $arg->{xform}) {
+    return sub {
+      map  { $_->[1] }
+      sort {
+        (exists $score{$a->[0]} && exists $score{$b->[0]}) ? ($score{$a->[0]} <=> $score{$b->[0]})
+                                                || ($fallback ? $fallback->($a->[0], $b->[0], $a->[1], $b->[1]) : 0)
+      : exists $score{$a->[0]}                        ? -1
+      : exists $score{$b->[0]}                        ? 1
+      : ($fallback ? $fallback->($a->[0], $b->[0], $a->[1], $b->[1]) : 0)
+      } map { [ $xf->($_), $_ ] } @_;
+    }
+  }
+
   sub {
     sort {
       (exists $score{$a} && exists $score{$b}) ? ($score{$a} <=> $score{$b})
